@@ -2,6 +2,8 @@ from typing import Type
 
 from mercury_engine_data_structures.formats.base_resource import BaseResource, AssetType
 from mercury_engine_data_structures.formats.bmbls import Bmbls
+from mercury_engine_data_structures.formats.bmmap import Bmmap
+from mercury_engine_data_structures.formats.bmmdef import Bmmdef
 from mercury_engine_data_structures.formats.bmsad import Bmsad
 from mercury_engine_data_structures.formats.bmscc import Bmscc
 from mercury_engine_data_structures.formats.bmssd import Bmssd
@@ -17,6 +19,8 @@ from mercury_engine_data_structures.formats.txt import Txt
 ALL_FORMATS = {
     "PKG": Pkg,
     "BMBLS": Bmbls,
+    "BMMAP": Bmmap,
+    "BMMDEF": Bmmdef,
     "BMSSD": Bmssd,
     "BMSAD": Bmsad,
     "BRFLD": Brfld,
